@@ -19,6 +19,7 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
 import java.util.function.Consumer;
 import java.util.function.Supplier;
@@ -40,14 +41,17 @@ import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuB
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
+import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableEditorSearchIndex;
 import org.drools.workbench.screens.guided.dtable.client.editor.search.GuidedDecisionTableSearchableElement;
 import org.drools.workbench.screens.guided.dtable.client.editor.search.SearchableElementFactory;
+import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableConstants;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
+import org.drools.workbench.screens.guided.dtable.shared.XLSConversionResult;
 import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
@@ -55,10 +59,11 @@ import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuIt
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
-import org.kie.workbench.common.widgets.client.search.common.EditorSearchIndex;
 import org.kie.workbench.common.widgets.client.search.common.HasSearchableElements;
+import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.kie.workbench.common.widgets.client.search.component.SearchBarComponent;
 import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
@@ -82,6 +87,8 @@ import org.uberfire.lifecycle.OnStartup;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
+import org.uberfire.workbench.model.menu.MenuFactory;
+import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
 
 import static org.uberfire.client.annotations.WorkbenchEditor.LockingStrategy.EDITOR_PROVIDED;
@@ -93,14 +100,20 @@ import static org.uberfire.client.annotations.WorkbenchEditor.LockingStrategy.ED
 @WorkbenchEditor(identifier = "GuidedDecisionTableEditor", supportedTypes = {GuidedDTableResourceType.class}, lockingStrategy = EDITOR_PROVIDED)
 public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableEditorPresenter implements HasSearchableElements<GuidedDecisionTableSearchableElement> {
 
+    public static final String IDENTIFIER = "GuidedDecisionTableEditor";
+
     private final SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
 
-    private final EditorSearchIndex<GuidedDecisionTableSearchableElement> editorSearchIndex;
+    private final GuidedDecisionTableEditorSearchIndex editorSearchIndex;
 
     private final SearchBarComponent<GuidedDecisionTableSearchableElement> searchBarComponent;
 
     private final SearchableElementFactory searchableElementFactory;
 
+    private MenuItem convertMenuItem = null;
+
+    private final Event<SearchPerformedEvent> searchPerformedEvent;
+
     @Inject
     public GuidedDecisionTableEditorPresenter(final View view,
                                               final Caller<GuidedDecisionTableEditorService> service,
@@ -108,6 +121,8 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                                               final PerspectiveManager perspectiveManager,
                                               final Event<NotificationEvent> notification,
                                               final Event<DecisionTableSelectedEvent> decisionTableSelectedEvent,
+                                              final GuidedDecisionTableDocksHandler guidedDecisionTableDocksHandler,
+                                              final AnalysisReportScreen analysisReportScreen,
                                               final ValidationPopup validationPopup,
                                               final GuidedDTableResourceType resourceType,
                                               final EditMenuBuilder editMenuBuilder,
@@ -121,15 +136,18 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                                               final SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder,
                                               final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder,
                                               final DownloadMenuItemBuilder downloadMenuItemBuilder,
-                                              final EditorSearchIndex<GuidedDecisionTableSearchableElement> editorSearchIndex,
+                                              final GuidedDecisionTableEditorSearchIndex editorSearchIndex,
                                               final SearchBarComponent<GuidedDecisionTableSearchableElement> searchBarComponent,
-                                              final SearchableElementFactory searchableElementFactory) {
+                                              final SearchableElementFactory searchableElementFactory,
+                                              final Event<SearchPerformedEvent> searchPerformedEvent) {
         super(view,
               service,
               docks,
               perspectiveManager,
               notification,
               decisionTableSelectedEvent,
+              guidedDecisionTableDocksHandler,
+              analysisReportScreen,
               validationPopup,
               resourceType,
               editMenuBuilder,
@@ -147,19 +165,28 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
         this.editorSearchIndex = editorSearchIndex;
         this.searchBarComponent = searchBarComponent;
         this.searchableElementFactory = searchableElementFactory;
+        this.searchPerformedEvent = searchPerformedEvent;
+
+        this.modeller.analysisReportScreen(analysisReportScreen);
     }
 
     @Override
     @PostConstruct
     public void init() {
         super.init();
-        editorSearchIndex.setIsDirtySupplier(getIsDirtySupplier());
+        editorSearchIndex.setCurrentAssetHashcodeSupplier(getCurrentHashCodeSupplier());
         editorSearchIndex.setNoResultsFoundCallback(getNoResultsFoundCallback());
+        editorSearchIndex.setSearchPerformedCallback(getSearchPerformedCallback());
+        editorSearchIndex.setSearchClosedCallback(getSearchClosedCallback());
         editorSearchIndex.registerSubIndex(this);
 
         setupSearchComponent();
     }
 
+    protected Supplier<Integer> getCurrentHashCodeSupplier() {
+        return () -> currentHashCode(getActiveDocument());
+    }
+
     private void setupSearchComponent() {
         final HTMLElement element = searchBarComponent.getView().getElement();
 
@@ -167,8 +194,29 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
         getKieEditorWrapperMultiPage().addTabBarWidget(getWidget(element));
     }
 
+    Command getSearchPerformedCallback() {
+        return () -> {
+            final Optional<GuidedDecisionTableSearchableElement> current = editorSearchIndex.getCurrentResult();
+
+            GuidedDecisionTableSearchableElement value = null;
+            if (current.isPresent()) {
+                value = current.get();
+            }
+
+            final SearchPerformedEvent event = new SearchPerformedEvent(value);
+            searchPerformedEvent.fire(event);
+        };
+    }
+
+    Command getSearchClosedCallback() {
+        return () -> highlightHelper().clearHighlight();
+    }
+
     Command getNoResultsFoundCallback() {
-        return () -> highlightHelper().clearSelections();
+        return () -> {
+            highlightHelper().clearSelections();
+            highlightHelper().clearHighlight();
+        };
     }
 
     private GridHighlightHelper highlightHelper() {
@@ -196,6 +244,11 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
         super.onFocus();
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return GuidedDecisionTableEditorPresenter.IDENTIFIER;
+    }
+
     @Override
     public void loadDocument(final ObservablePath path,
                              final PlaceRequest placeRequest) {
@@ -214,7 +267,7 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
 
         for (int row = 0, dataSize = data.size(); row < dataSize; row++) {
             for (int column = 0; column < data.get(row).size(); column++) {
-                searchableElements.add(makeSearchableElement(data, row, column));
+                searchableElements.add(makeSearchableElement(data, row, column, model));
             }
         }
 
@@ -223,9 +276,10 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
 
     private GuidedDecisionTableSearchableElement makeSearchableElement(final List<List<DTCellValue52>> data,
                                                                        final int row,
-                                                                       final int column) {
+                                                                       final int column,
+                                                                       final GuidedDecisionTable52 model) {
         final DTCellValue52 cellValue52 = data.get(row).get(column);
-        return searchableElementFactory.makeSearchableElement(row, column, cellValue52, modeller);
+        return searchableElementFactory.makeSearchableElement(row, column, cellValue52, null, model, modeller);
     }
 
     protected RemoteCallback<GuidedDecisionTableEditorContent> getLoadContentSuccessCallback(final ObservablePath path,
@@ -314,6 +368,8 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                         .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
                 addDownloadMenuItem(fileMenuBuilder);
 
+                fileMenuBuilder.addNewTopLevelMenu(getConvertMenuItem());
+
                 this.menus = fileMenuBuilder.build();
 
                 return promises.resolve();
@@ -323,6 +379,29 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
         return promises.resolve();
     }
 
+    private MenuItem getConvertMenuItem() {
+        if (convertMenuItem == null) {
+
+            convertMenuItem = MenuFactory.newTopLevelMenu(GuidedDecisionTableConstants.INSTANCE.Convert())
+                    .respondsWith(() -> onConvert())
+                    .endMenu()
+                    .build()
+                    .getItems()
+                    .get(0);
+        }
+        return convertMenuItem;
+    }
+
+    public void onConvert() {
+        service.call((RemoteCallback<XLSConversionResult>) result -> {
+            if (result.isConverted()) {
+                view.showConversionSuccess();
+            } else {
+                view.showConversionMessage(result.getMessage());
+            }
+        }).convert(versionRecordManager.getCurrentPath());
+    }
+
     protected Command getSaveAndRenameCommand() {
 
         return saveAndRenameCommandBuilder
