@@ -54,6 +54,7 @@ import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.kie.workbench.common.widgets.client.source.ViewDRLSourceWidget;
@@ -186,6 +187,9 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
     @Mock
     private EventSourceMock<SearchPerformedEvent> searchPerformed;
 
+    @Mock
+    private AnalysisReportScreen analysisReportScreen;
+
     private Event<SaveInProgressEvent> saveInProgressEvent = spy(new EventSourceMock<SaveInProgressEvent>() {
         @Override
         public void fire(final SaveInProgressEvent event) {
@@ -221,6 +225,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                                                            notification,
                                                            saveInProgressEvent,
                                                            decisionTableSelectedEvent,
+                                                           mock(GuidedDecisionTableDocksHandler.class),
+                                                           analysisReportScreen,
                                                            validationPopup,
                                                            dtGraphResourceType,
                                                            editMenuBuilder,
@@ -266,6 +272,11 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
         };
     }
 
+    @Test
+    public void analysisScreenIsSetForModeller() {
+        verify(modeller).analysisReportScreen(analysisReportScreen);
+    }
+
     @Test
     @SuppressWarnings("unchecked")
     public void checkInit() {
@@ -1689,6 +1700,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                                                            notification,
                                                            saveInProgressEvent,
                                                            decisionTableSelectedEvent,
+                                                           mock(GuidedDecisionTableDocksHandler.class),
+                                                           mock(AnalysisReportScreen.class),
                                                            validationPopup,
                                                            dtGraphResourceType,
                                                            editMenuBuilder,
