@@ -33,16 +33,12 @@ public interface ScenarioEditorView
         void onRunScenario();
 
         void onRedraw();
-
-        void onRunAllScenarios();
     }
 
     void setPresenter(Presenter presenter);
 
     MenuItem getRunScenarioMenuItem();
 
-    MenuItem getRunAllScenariosMenuItem();
-
     void showResults();
 
     void renderFixtures(Path path, AsyncPackageDataModelOracle oracle, Scenario scenario);
